
#define INTERFACE_H

/****************************************************************

    Copyright (c) 1996-1997 Fred Pesch

    This program is free software; you can redistribute it 
    and/or modify it under the terms of the GNU General 
    Public License as published by the Free Software 
    Foundation (version 2 of the License).

    This program is distributed in the hope that it will 
    be useful, but WITHOUT ANY WARRANTY; without even the 
    implied warranty of MERCHANTABILITY or FITNESS FOR A 
    PARTICULAR PURPOSE.  See the GNU General Public License 
    for more details.

    For a copy of the GNU General Public License, write to the 
    Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
    MA 02139, USA.

****************************************************************/

#include <Xm/XmAll.h>
#include <stdio.h>

#include "dirtree.h"
#include "error_handler.h"
#include "dialogs.h"
#include "config.h"

#ifdef EDITRES_COMPLIANT
  #include <X11/Xmu/Editres.h>
#endif

/* Globals */

Widget W_App=NULL, W_MainWindow=NULL;
Widget W_TreeContainer=NULL;
Widget W_ScrollTree=NULL;

Widget W_ListFile=NULL;
Widget W_ScrollList=NULL;

Widget W_MessageLabel=NULL;

/* Dialogs Widgets */
Widget W_MessageDialog=NULL;
Widget W_ConfirmDialog=NULL;

Widget W_CopyDialog=NULL;
Widget W_MoveDialog=NULL;
Widget W_DeleteDialog=NULL;
Widget W_RenameDialog=NULL;
Widget W_AttributesDialog=NULL;
Widget W_CreateDialog=NULL;
Widget W_ExecDialog=NULL;
Widget W_InfoDialog=NULL;

Widget W_TarDialog=NULL;
Widget W_UnTarDialog=NULL;
Widget W_GZipDialog=NULL;
Widget W_GUnZipDialog=NULL;
Widget W_EncodeDialog=NULL;
Widget W_DecodeDialog=NULL;
Widget W_SplitDialog=NULL;
Widget W_UnSplitDialog=NULL;
Widget W_SelectFilterDialog=NULL;
Widget W_GoToDirDialog=NULL;
Widget W_StatusDialog=NULL;
Widget W_DropDialog=NULL;

XtAppContext AppContext;

typedef struct {
  Pixmap pixmap;
  char *extension;
} TUserFilePixmap;

TUserFilePixmap *UserFilePixmapList;


/* Fallback resources */

String Fallbacks[]= {
#include "Fallbacks.res"
};

void WriteMessageLabel(char *message)
{
  XmString string;

  string = NULL;
  string = XmStringCreateSimple(message);

  if(string==NULL)
    FatalError("interface.c", "WriteMessageLabel", "Unable to create info string (XmStringCreateSimple failed)");
  
  XtVaSetValues(W_MessageLabel, XmNlabelString, string, NULL, NULL);
  XmStringFree(string);

}

void InitInterface(int argc, char **argv)
{
  Widget w_temp1, w_temp2, w_temp3, w_temp4, w_temp5, w_temp6, w_temp7;
  Widget w_menubar;
  Widget w_mainframe;
  Widget w_messageframe;
  Widget w_menubutton;
  Widget w_viewmenu;
  Widget w_viewbutton;
  Widget w_sortmenu;
  Widget w_sortbutton;

  W_App = XtAppInitialize(&AppContext, "Fof", NULL, 0, &argc, argv, Fallbacks, NULL, 0);


#ifdef EDITRES_COMPLIANT

  XtAddEventHandler(W_App, (EventMask) 0, True, (XtEventHandler) _XEditResCheckMessages, NULL);

#endif

  /* Create the Main Window manually */

  W_MainWindow=XtVaCreateManagedWidget("MainWindow", xmMainWindowWidgetClass, W_App, NULL);

  /* Message bar */

  w_messageframe=XtVaCreateManagedWidget("MessageFrame", xmFrameWidgetClass, W_MainWindow, NULL);

  w_temp2=XtVaCreateManagedWidget("MessageWindow", xmFormWidgetClass, w_messageframe, NULL);

  w_temp3=XtVaCreateManagedWidget("DateLabel", xmLabelWidgetClass, w_temp2, 
				  XmNleftAttachment, XmATTACH_FORM, NULL);

  w_temp4=XtVaCreateManagedWidget("MessageSeparator", xmSeparatorWidgetClass, w_temp2, 
				  XmNleftAttachment, XmATTACH_WIDGET, 
				  XmNleftWidget, w_temp3, 
				  XmNtopAttachment, XmATTACH_FORM, 
				  XmNbottomAttachment, XmATTACH_FORM, 
				  XmNorientation, XmVERTICAL, 
				  NULL);

  W_MessageLabel=XtVaCreateManagedWidget("MessageLabel", xmLabelWidgetClass, w_temp2, 
					 XmNleftAttachment, XmATTACH_WIDGET, 
					 XmNleftWidget, w_temp4, 
					 NULL);

  /* Main frame */

  w_mainframe=XtVaCreateManagedWidget("MainFrame", xmPanedWindowWidgetClass, W_MainWindow, 
				      XmNorientation, XmHORIZONTAL, 
				      XmNallowResize, True, 
				      NULL);

 
  /* Tree Container */

  w_temp3=XtVaCreateManagedWidget("ContainerFrame", xmFrameWidgetClass, w_mainframe, NULL);

  w_temp4=XtVaCreateManagedWidget("HostLabel", xmLabelWidgetClass, w_temp3, 
				  XmNchildType, XmFRAME_TITLE_CHILD, 
				  NULL);

  W_ScrollTree=XtVaCreateManagedWidget("TreeWindow", xmScrolledWindowWidgetClass, w_temp3, 
				       XmNchildType, XmFRAME_WORKAREA_CHILD, 
				       XmNscrollingPolicy, XmAUTOMATIC, 
				       NULL);

  W_TreeContainer=XtVaCreateManagedWidget("TreeContainer", xmContainerWidgetClass, W_ScrollTree, 
					  XmNentryViewType, XmSMALL_ICON, 
					  XmNlayoutType, XmDETAIL, 
					  XmNselectionPolicy, XmSINGLE_SELECT, 
					  XmNdetailColumnHeadingCount, 2,
					  XmNdetailOrderCount, 1, 
					  NULL);

  /* File List */

  w_temp3=XtVaCreateManagedWidget("FileListFrame", xmFrameWidgetClass, w_mainframe, NULL);

  w_temp4=XtVaCreateManagedWidget("CurrentDirLabel", xmLabelWidgetClass, w_temp3, 
				  XmNchildType, XmFRAME_TITLE_CHILD, 
				  NULL);

  W_ScrollList=XtVaCreateManagedWidget("FileListWindow", xmScrolledWindowWidgetClass, w_temp3, 
				       XmNchildType, XmFRAME_WORKAREA_CHILD, 
				       XmNscrollingPolicy, XmAUTOMATIC, 
				       XmNscrollBarDisplayPolicy, XmSTATIC, 
				       NULL);

  W_ListFile=XtVaCreateManagedWidget("FileListContainer", xmContainerWidgetClass, W_ScrollList, 
				     XmNentryViewType, XmLARGE_ICON, 
				     XmNlayoutType, XmSPATIAL, 
				     XmNspatialSnapModel, XmCENTER, 
				     XmNspatialStyle, XmCELLS, 
				     XmNspatialIncludeModel, XmAPPEND, 
				     XmNspatialResizeModel, XmGROW_MINOR, 
				     XmNdetailColumnHeadingCount, 6, 
				     XmNdetailOrderCount, 5, 
				     NULL);

  /* Menu bar creation */


  w_menubar=XmCreateMenuBar(W_MainWindow, "MenuBar", NULL, 0);

  /* File Menu */
 
  w_temp4=XmCreatePulldownMenu(w_menubar, "FileMenu", NULL, 0);
  w_temp3=XtVaCreateManagedWidget("FileMenuButton", xmCascadeButtonWidgetClass, w_menubar, XmNsubMenuId, w_temp4, NULL);
 
  w_temp5=XtVaCreateManagedWidget("CopyButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("MoveButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("DeleteButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("RenameButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("AttributesButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("CreateButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("ExecButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("InfoButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("ViewButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("EditButton", xmPushButtonWidgetClass, w_temp4, NULL);

  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("QuitOthersButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("QuitAllButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);

  w_temp5=XtVaCreateManagedWidget("QuitButton", xmPushButtonWidgetClass, w_temp4, NULL);

  /* Archive Menu */

  w_temp4=XmCreatePulldownMenu(w_menubar, "ArcMenu", NULL, 0);
  w_temp3=XtVaCreateManagedWidget("ArcMenuButton", xmCascadeButtonWidgetClass, w_menubar, XmNsubMenuId, w_temp4, NULL);

  w_temp5=XtVaCreateManagedWidget("TarButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("UnTarButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("GZipButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("GUnZipButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("EncodeButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("DecodeButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("SplitButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("UnSplitButton", xmPushButtonWidgetClass, w_temp4, NULL);

  /* Selection Menu */

  w_temp4=XmCreatePulldownMenu(w_menubar, "SelectMenu", NULL, 0);
  w_temp3=XtVaCreateManagedWidget("SelectMenuButton", xmCascadeButtonWidgetClass, w_menubar, XmNsubMenuId, w_temp4, NULL);

  w_temp5=XtVaCreateManagedWidget("SelectAllButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("UnSelectAllButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("FilterButton", xmPushButtonWidgetClass, w_temp4, NULL);
 
  /* Filemanager menu */

  w_temp4=XmCreatePulldownMenu(w_menubar, "SystemMenu", NULL, 0);
  w_temp3=XtVaCreateManagedWidget("SystemMenuButton", xmCascadeButtonWidgetClass, w_menubar, XmNsubMenuId, w_temp4, NULL);

  w_temp5=XtVaCreateManagedWidget("NewFofButton", xmPushButtonWidgetClass, w_temp4, NULL);

  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);

  w_temp6=XmCreatePulldownMenu(w_temp5, "WindowsMenu", NULL, 0);
  w_temp5=XtVaCreateManagedWidget("WindowsButton", xmCascadeButtonWidgetClass, w_temp4, XmNsubMenuId, w_temp6, NULL);

  w_temp7=XtVaCreateManagedWidget("TileButton", xmPushButtonWidgetClass, w_temp6, NULL); 
  w_temp7=XtVaCreateManagedWidget("StackButton", xmPushButtonWidgetClass, w_temp6, NULL); 
  w_temp7=XtVaCreateManagedWidget("CascadeButton", xmPushButtonWidgetClass, w_temp6, NULL); 
  w_temp7=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp6, NULL); 

  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
 
  w_temp6=XmCreatePulldownMenu(w_temp5, "RefreshMenu", NULL, 0);
  w_temp5=XtVaCreateManagedWidget("RefreshButton", xmCascadeButtonWidgetClass, w_temp4, XmNsubMenuId, w_temp6, NULL);

  w_temp7=XtVaCreateManagedWidget("RefreshTreeButton", xmPushButtonWidgetClass, w_temp6, NULL);
  w_temp7=XtVaCreateManagedWidget("RefreshFileListButton", xmPushButtonWidgetClass, w_temp6, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("HomeDirButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("GoToDirButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);

  w_temp6=XmCreatePulldownMenu(w_temp5, "ViewMenu", NULL, 0);
  w_viewmenu=w_temp6;

  w_temp5=XtVaCreateManagedWidget("ViewTypeButton", xmCascadeButtonWidgetClass, w_temp4, XmNsubMenuId, w_temp6, NULL);


  w_temp7=XtVaCreateManagedWidget("ViewLargeButton", xmToggleButtonWidgetClass, w_temp6, NULL);
   w_viewbutton=w_temp7;

  w_temp7=XtVaCreateManagedWidget("ViewSmallButton", xmToggleButtonWidgetClass, w_temp6, NULL);
  w_temp7=XtVaCreateManagedWidget("ViewDetailButton", xmToggleButtonWidgetClass, w_temp6, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);

  w_temp6=XmCreatePulldownMenu(w_temp5, "SortMenu", NULL, 0);
  w_sortmenu=w_temp6,
  w_temp5=XtVaCreateManagedWidget("SortButton", xmCascadeButtonWidgetClass, w_temp4, XmNsubMenuId, w_temp6, NULL);

  w_temp7=XtVaCreateManagedWidget("SortByTypeButton", xmToggleButtonWidgetClass, w_temp6, NULL);
  w_sortbutton=w_temp7;
  w_temp7=XtVaCreateManagedWidget("SortByNameButton", xmToggleButtonWidgetClass, w_temp6, NULL);
  w_temp7=XtVaCreateManagedWidget("SortBySizeButton", xmToggleButtonWidgetClass, w_temp6, NULL);


  /* Tools Menu */

  w_temp4=XmCreatePulldownMenu(w_menubar, "ToolsMenu", NULL, 0);
  w_temp3=XtVaCreateManagedWidget("ToolsMenuButton", xmCascadeButtonWidgetClass, w_menubar, XmNsubMenuId, w_temp4, NULL);

  w_temp5=XtVaCreateManagedWidget("ShellWindowButton", xmPushButtonWidgetClass, w_temp4, NULL);
   w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
 
  w_temp5=XtVaCreateManagedWidget("FindWindowButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("FindCurWindowButton", xmPushButtonWidgetClass, w_temp4, NULL);

  /* User Menu */

  w_temp4=XmCreatePulldownMenu(w_menubar, "UserMenu", NULL, 0);
  w_temp3=XtVaCreateManagedWidget("UserMenuButton", xmCascadeButtonWidgetClass, w_menubar, XmNsubMenuId, w_temp4, NULL);

  /* Help Menu */

  w_temp4=XmCreatePulldownMenu(w_menubar, "HelpMenu", NULL, 0);
  w_menubutton=XtVaCreateManagedWidget("HelpMenuButton", xmCascadeButtonWidgetClass, w_menubar, XmNsubMenuId, w_temp4, NULL);


  w_temp5=XtVaCreateManagedWidget("OverviewButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("BeginnerButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("ReferenceButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("ConfigureButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("LicenseButton", xmPushButtonWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("MenuSeparator", xmSeparatorWidgetClass, w_temp4, NULL);
  w_temp5=XtVaCreateManagedWidget("AboutButton", xmPushButtonWidgetClass, w_temp4, NULL);


  XtVaSetValues(W_MainWindow, 
		XmNmenuBar, w_menubar, 
		XmNmessageWindow, w_messageframe, 
		XmNworkWindow, w_mainframe, 
		NULL);

  XtVaSetValues(w_menubar, XmNmenuHelpWidget, w_menubutton, NULL);


  XtManageChild(w_menubar);

  /* menus with radio box behaviour */

  XtVaSetValues( w_viewmenu, 
		 XmNradioBehavior, True,
		 XmNradioAlwaysOne, True,
		 NULL);

  XmToggleButtonSetState(w_viewbutton, True, True);

  XtVaSetValues( w_sortmenu, 
		 XmNradioBehavior, True,
		 XmNradioAlwaysOne, True,
		 NULL);

  XmToggleButtonSetState(w_sortbutton, True, True);



  /* Message dialog */

  W_MessageDialog = XmCreateFormDialog(W_MainWindow, "MessageDialog", NULL, 0);

  w_temp1 = XtVaCreateManagedWidget("MessageBitmapFrame", xmFrameWidgetClass, W_MessageDialog,
				    XmNtopAttachment, XmATTACH_FORM,
				    XmNleftAttachment, XmATTACH_FORM,
				    NULL);

  w_temp2 = XtVaCreateManagedWidget("MessagePixmap", xmLabelWidgetClass, w_temp1,
				    XmNlabelType, XmPIXMAP,
				    NULL);


  w_temp3 = XtVaCreateManagedWidget("MessageOkButton", xmPushButtonWidgetClass, W_MessageDialog,
				    XmNbottomAttachment, XmATTACH_FORM,
				    XmNleftAttachment, XmATTACH_FORM,
				    XmNrightAttachment, XmATTACH_FORM,
				    NULL);

  
  w_temp2 = XtVaCreateManagedWidget("MessageSeparator", xmSeparatorWidgetClass, W_MessageDialog,
				    XmNbottomAttachment, XmATTACH_WIDGET,
				    XmNbottomWidget, w_temp3,
				    XmNleftAttachment, XmATTACH_FORM,
				    XmNrightAttachment, XmATTACH_FORM,
				    NULL);


  w_temp2 = XtVaCreateManagedWidget("MessageTextFrame", xmFrameWidgetClass, W_MessageDialog,
				    XmNtopAttachment, XmATTACH_FORM,
				    XmNleftAttachment, XmATTACH_WIDGET,
				    XmNleftWidget, w_temp1,
				    XmNrightAttachment, XmATTACH_FORM,
				    XmNbottomAttachment, XmATTACH_WIDGET,
				    XmNbottomWidget, w_temp2,
				    NULL);

  w_temp2 = XtVaCreateManagedWidget("MessageText", xmTextWidgetClass, w_temp2,
				    XmNeditable, False,
				    XmNeditMode, XmMULTI_LINE_EDIT,
				    XmNautoShowCursorPosition, False,
				    XmNcursorPositionVisible, False,
				    XmNwordWrap, True,
				    NULL);

  /* hard coded values for the dialog */ 

  XtVaSetValues(W_MessageDialog,
		XmNdefaultButton, w_temp3,
		XmNcancelButton, w_temp3,
		XmNdialogStyle, XmDIALOG_FULL_APPLICATION_MODAL,
		XmNresizePolicy, XmRESIZE_GROW,
		XmNautoUnmanage, True,
		NULL);
		
	      
  /* Remove decorations for dialogs */

  XtVaSetValues(XtParent(W_MessageDialog),
		XmNmwmDecorations, MWM_DECOR_ALL | MWM_DECOR_MAXIMIZE | MWM_DECOR_MINIMIZE | MWM_DECOR_MENU,
		NULL);  

  InitMessageDialog();

  /* Confirm dialog */

  W_ConfirmDialog = XmCreateFormDialog(W_MainWindow, "ConfirmDialog", NULL, 0);

  w_temp1 = XtVaCreateManagedWidget("ConfirmBitmapFrame", xmFrameWidgetClass, W_ConfirmDialog,
				    XmNtopAttachment, XmATTACH_FORM,
				    XmNleftAttachment, XmATTACH_FORM,
				    NULL);

  w_temp2 = XtVaCreateManagedWidget("ConfirmPixmap", xmLabelWidgetClass, w_temp1,
				    XmNlabelType, XmPIXMAP,
				    NULL);


  w_temp3 = XtVaCreateManagedWidget("ConfirmYesButton", xmPushButtonWidgetClass, W_ConfirmDialog,
				    XmNbottomAttachment, XmATTACH_FORM,
				    XmNleftAttachment, XmATTACH_POSITION,	
				    XmNleftPosition, 4,
				    XmNrightAttachment, XmATTACH_POSITION,
				    XmNrightPosition, 46,
				    NULL);

  w_temp4 = XtVaCreateManagedWidget("ConfirmNoButton", xmPushButtonWidgetClass, W_ConfirmDialog,
				    XmNbottomAttachment, XmATTACH_FORM,
				    XmNleftAttachment, XmATTACH_POSITION,
				    XmNleftPosition, 54,
				    XmNrightAttachment, XmATTACH_POSITION,
				    XmNrightPosition, 96,
				    NULL);

  
  w_temp2 = XtVaCreateManagedWidget("ConfirmSeparator", xmSeparatorWidgetClass, W_ConfirmDialog,
				    XmNbottomAttachment, XmATTACH_WIDGET,
				    XmNbottomWidget, w_temp3,
				    XmNleftAttachment, XmATTACH_FORM,
				    XmNrightAttachment, XmATTACH_FORM,
				    NULL);


  w_temp2 = XtVaCreateManagedWidget("ConfirmTextFrame", xmFrameWidgetClass, W_ConfirmDialog,
				    XmNtopAttachment, XmATTACH_FORM,
				    XmNleftAttachment, XmATTACH_WIDGET,
				    XmNleftWidget, w_temp1,
				    XmNrightAttachment, XmATTACH_FORM,
				    XmNbottomAttachment, XmATTACH_WIDGET,
				    XmNbottomWidget, w_temp2,
				    NULL);

  w_temp2 = XtVaCreateManagedWidget("ConfirmText", xmTextWidgetClass, w_temp2,
				    XmNeditable, False,
				    XmNeditMode, XmMULTI_LINE_EDIT,
				    XmNautoShowCursorPosition, False,
				    XmNcursorPositionVisible, False,
				    XmNwordWrap, True,
				    NULL);

  /* hard coded values for the dialog */ 

  XtVaSetValues(W_ConfirmDialog,
		XmNdefaultButton, w_temp4,
		XmNcancelButton, w_temp4,
		XmNdialogStyle, XmDIALOG_FULL_APPLICATION_MODAL,
		XmNresizePolicy, XmRESIZE_GROW,
		XmNautoUnmanage, True,
		NULL);
		
	      
  /* Remove decorations for dialogs */

  XtVaSetValues(XtParent(W_ConfirmDialog),
		XmNmwmDecorations, MWM_DECOR_ALL | MWM_DECOR_MAXIMIZE | MWM_DECOR_MINIMIZE | MWM_DECOR_MENU,
		NULL);  

  InitConfirmDialog();

  /* Status dialog */

  W_StatusDialog = XmCreateFormDialog(W_MainWindow, "StatusDialog", NULL, 0);

  
  w_temp1 = XtVaCreateManagedWidget("StatusLabel1", xmLabelWidgetClass, W_StatusDialog,
				    XmNtopAttachment, XmATTACH_FORM,
				    XmNleftAttachment, XmATTACH_FORM,
				    XmNrightAttachment, XmATTACH_FORM,
				    NULL);

  w_temp1 = XtVaCreateManagedWidget("StatusSeparator2", xmSeparatorWidgetClass, W_StatusDialog,
				    XmNtopAttachment, XmATTACH_WIDGET,
				    XmNtopWidget, w_temp1,
				    XmNleftAttachment, XmATTACH_FORM,
				    XmNrightAttachment, XmATTACH_FORM,
				    NULL);
  
  w_temp1 = XtVaCreateManagedWidget("StatusScale", xmScaleWidgetClass, W_StatusDialog,
				    XmNtopAttachment, XmATTACH_WIDGET,
				    XmNtopWidget, w_temp1,
				    XmNleftAttachment, XmATTACH_FORM,
				    XmNrightAttachment, XmATTACH_FORM,
				    XmNslidingMode, XmTHERMOMETER,
				    XmNorientation, XmHORIZONTAL,
				    NULL);

  w_temp1 = XtVaCreateManagedWidget("StatusSeparator3", xmSeparatorWidgetClass, W_StatusDialog,
				    XmNtopAttachment, XmATTACH_WIDGET,
				    XmNtopWidget, w_temp1,
				    XmNleftAttachment, XmATTACH_FORM,
				    XmNrightAttachment, XmATTACH_FORM,
				    NULL);

  w_temp2 = XtVaCreateManagedWidget("StatusStopButton", xmPushButtonWidgetClass, W_StatusDialog,
				    XmNbottomAttachment, XmATTACH_FORM,
				    XmNrightAttachment, XmATTACH_FORM,
				    XmNsensitive, False,
				    NULL);

  w_temp2 = XtVaCreateManagedWidget("StatusOkButton", xmPushButtonWidgetClass, W_StatusDialog,
				    XmNbottomAttachment, XmATTACH_FORM,
				    XmNleftAttachment, XmATTACH_FORM,
				    XmNrightAttachment, XmATTACH_WIDGET,
				    XmNrightWidget, w_temp2,
				    XmNsensitive, False,
				    NULL);

  w_temp2 =  XtVaCreateManagedWidget("StatusSeparator1", xmSeparatorWidgetClass, W_StatusDialog,
				     XmNbottomAttachment, XmATTACH_WIDGET,
				     XmNbottomWidget, w_temp2,
				     XmNleftAttachment, XmATTACH_FORM,
				     XmNrightAttachment, XmATTACH_FORM,
				     XmNsensitive, False,
				     NULL);


  w_temp2 = XtVaCreateManagedWidget("StatusScroll", xmScrolledWindowWidgetClass, W_StatusDialog,
				    XmNtopAttachment, XmATTACH_WIDGET,
				    XmNtopWidget, w_temp1,
				    XmNleftAttachment, XmATTACH_FORM,
				    XmNrightAttachment, XmATTACH_FORM,
				    XmNscrollingPolicy, XmAUTOMATIC,
				    XmNbottomAttachment, XmATTACH_WIDGET,
				    XmNbottomWidget, w_temp2,
				    NULL);

  w_temp2 = XtVaCreateManagedWidget("StatusText", xmTextWidgetClass, w_temp2,
				    XmNeditable, False,
				    XmNeditMode, XmMULTI_LINE_EDIT,
				    XmNautoShowCursorPosition, False,
				    XmNcursorPositionVisible, False,
				    NULL);

  /* hard coded values for the dialog */ 

  XtVaSetValues(W_StatusDialog,
		XmNdialogStyle, XmDIALOG_FULL_APPLICATION_MODAL,
		XmNresizePolicy, XmRESIZE_GROW,
		NULL);
		
	      
  /* Remove decorations for dialogs */

  XtVaSetValues(XtParent(W_StatusDialog),
		XmNmwmDecorations, MWM_DECOR_ALL | MWM_DECOR_MAXIMIZE | MWM_DECOR_MINIMIZE | MWM_DECOR_MENU,
		NULL);  

}
 
